@@ -1,20 +1,13 @@
 #!/usr/bin/env python
 
-# Copyright (C) 2007 Christian Dywan <christian at twotoasts dot de>
+# Copyright (C) 2007-2008 Christian Dywan <christian at twotoasts dot de>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+# See the file COPYING for the full license text.
 
 import sys
 
@@ -41,7 +34,7 @@ except ImportError, msg:
     print 'Warning: The optional module %s is missing.' % str(msg).split()[-1]
 
 app_name = 'catfish'
-app_version = '0.3'
+app_version = '0.3.2'
 
 _ = gettext.gettext # i18n shortcut
 
@@ -134,19 +127,33 @@ class catfish:
     def __init__(self):
         """Create the main window."""
 
-        self.openwrappers = ['gnome-open', 'exo-open', 'xdg-open']
-        # Guess default fileman
-        if os.environ.get('DESKTOP_SESSION', os.environ.get('GDMSESSION', ''))[:4] == 'xfce':
+        # Check for a desktop environment
+        desktop = os.environ.get('DESKTOP_SESSION', os.environ.get('GDMSESSION', ''))
+        if desktop[:4] == 'xfce':
+            # We assume this is Xfce4
             default_fileman = 'Thunar'
             self.open_wrapper = 'exo-open'
-        else:
+        elif desktop[:5] == 'gnome':
+            # We assume this is Gnome
             default_fileman = 'Nautilus'
+            self.open_wrapper = 'gnome-open'
+        else:
+            # Unknown desktop? Just see what we have then
+            # Guess suitable fileman
+            commands = ['Nautilus', 'Thunar', 'konqueror']
+            default_fileman = ''
+            for path in os.environ.get('PATH', '/usr/bin').split(os.pathsep):
+                for command in commands:
+                    if os.path.exists(os.path.join(path, command)):
+                        default_fileman = command
+                        break
+            commands = ['gnome-open', 'exo-open', 'xdg-open']
             self.open_wrapper = ''
             # Guess suitable file open wrapper
             for path in os.environ.get('PATH', '/usr/bin').split(os.pathsep):
-                for wrapper in self.openwrappers:
-                    if os.path.exists(os.path.join(path, wrapper)):
-                        self.open_wrapper = wrapper
+                for command in commands:
+                    if os.path.exists(os.path.join(path, command)):
+                        self.open_wrapper = command
                         break
 
         # Parse command line options
@@ -188,6 +195,9 @@ class catfish:
             print '(The default is "open".)'
             sys.exit(1)
 
+        if not self.options.fileman:
+            print 'Warning: No file manager was found or specified.'
+
         # Prepare i18n using gettext
         try:
             locale.setlocale(locale.LC_ALL, '')
@@ -480,7 +490,9 @@ class catfish:
                 if self.options.debug: print 'Debug:', msg
                 self.get_error_dialog(('Error: Could not open the file %s.'
                  % filename), self.window_search)
-                print 'Note:  The wrapper was %s.' % self.open_wrapper
+                print '* The wrapper was %s.' % self.open_wrapper
+                print '* The filemanager was %s.' % self.options.fileman
+                print 'Hint: Check wether the wrapper and filemanager exist.'
         except Exception, msg:
             if self.options.debug: print 'Debug:', msg
             self.get_error_dialog(('Error: Could not access the file %s.'
@@ -498,7 +510,7 @@ class catfish:
         folder = os.path.expanduser(folder)
         method_name = [method, 'locate'][method=='slocate']
         methods = {
-            'find': (method, '', '%s ' + folder + ' -ignore_readdir_race -noleaf',
+            'find': (method, '', '%s "' + folder + '" -ignore_readdir_race -noleaf',
                 '-wholename', '-iwholename', '', 1, 1, 0, 0, 0),
             'locate': (method, '', '%s', '', '-i', '-n %i' % limit,
                 1, 0, 1, 0, 0),
